@@ -2,7 +2,7 @@
 ## Stripe API - ~/lib/Net/API/Stripe/Billing/Subscription/Item.pm
 ## Version v0.1.1
 ## Copyright(c) 2020 DEGUEST Pte. Ltd.
-## Author: Jacques Deguest <@sitael.tokyo.deguest.jp>
+## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2019/11/02
 ## Modified 2020/05/15
 ## 
@@ -12,30 +12,37 @@ package Net::API::Stripe::Billing::Subscription::Item;
 BEGIN
 {
     use strict;
+    use warnings;
     use parent qw( Net::API::Stripe::Generic );
+    use vars qw( $VERSION );
     our( $VERSION ) = 'v0.1.1';
 };
 
-sub id { shift->_set_get_scalar( 'id', @_ ); }
+use strict;
+use warnings;
 
-sub object { shift->_set_get_scalar( 'object', @_ ); }
+sub id { return( shift->_set_get_scalar( 'id', @_ ) ); }
+
+sub object { return( shift->_set_get_scalar( 'object', @_ ) ); }
 
 sub billing_thresholds { return( shift->_set_get_object( 'billing_thresholds', 'Net::API::Stripe::Billing::Thresholds', @_ ) ); }
 
 ## Used in upcoming invoice api calls
 sub clear_usage { return( shift->_set_get_boolean( 'clear_usage', @_ ) ); }
 
-sub created { shift->_set_get_datetime( 'created', @_ ); }
+sub created { return( shift->_set_get_datetime( 'created', @_ ) ); }
 
 sub deleted { return( shift->_set_get_boolean( 'deleted', @_ ) ); }
 
-sub metadata { shift->_set_get_hash( 'metadata', @_ ); }
+sub metadata { return( shift->_set_get_hash( 'metadata', @_ ) ); }
 
-sub plan { shift->_set_get_object( 'plan', 'Net::API::Stripe::Billing::Plan', @_ ); }
+sub plan { return( shift->_set_get_object( 'plan', 'Net::API::Stripe::Billing::Plan', @_ ) ); }
 
-sub quantity { shift->_set_get_number( 'quantity', @_ ); }
+sub price { return( shift->_set_get_object( 'price', 'Net::API::Stripe::Price', @_ ) ); }
 
-sub subscription { shift->_set_get_scalar( 'subscription', @_ ); }
+sub quantity { return( shift->_set_get_number( 'quantity', @_ ) ); }
+
+sub subscription { return( shift->_set_get_scalar( 'subscription', @_ ) ); }
 
 sub tax_rates { return( shift->_set_get_object_array( 'tax_rates', 'Net::API::Stripe::Tax::Rate', @_ ) ); }
 
@@ -68,33 +75,27 @@ Subscription items allow you to create customer subscriptions with more than one
 
 =head1 CONSTRUCTOR
 
-=over 4
-
-=item B<new>( %ARG )
+=head2 new( %ARG )
 
 Creates a new L<Net::API::Stripe::Billing::Subscription::Item> object.
 
-=back
-
 =head1 METHODS
 
-=over 4
-
-=item B<id> string
+=head2 id string
 
 Unique identifier for the object.
 
-=item B<object> string, value is "subscription_item"
+=head2 object string, value is "subscription_item"
 
 String representing the object’s type. Objects of the same type share the same value.
 
-=item B<billing_thresholds> hash
+=head2 billing_thresholds hash
 
 Define thresholds at which an invoice will be sent, and the related subscription advanced to a new billing period
 
 This is a L<Net::API::Stripe::Billing::Thresholds> object.
 
-=over 8
+=over 4
 
 =item I<usage_gte> integer
 
@@ -102,82 +103,86 @@ Usage threshold that triggers the subscription to create an invoice
 
 =back
 
-=item B<clear_usage>() optional
+=head2 clear_usage() optional
 
 Delete all usage for a given subscription item. Allowed only when deleted is set to true and the current plan’s usage_type is metered.
 
 This is used in making upcoming invoice items api calls as described here: L<https://stripe.com/docs/api/invoices/upcoming_invoice_lines>
 
-=item B<created> integer
+=head2 created integer
 
 Time at which the object was created. Measured in seconds since the Unix epoch.
 
-=item B<deleted> optional
+=head2 deleted optional
 
 A flag that, if set to true, will delete the specified item.
 
 This is used in making upcoming invoice items api calls as described here: L<https://stripe.com/docs/api/invoices/upcoming_invoice_lines>
 
-=item B<metadata> hash
+=head2 metadata hash
 
 Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
 
-=item B<plan> hash, plan object
+=head2 plan hash, plan object
 
 Hash describing the plan the customer is subscribed to.
 
 This is a L<Net::API::Stripe::Billing::Plan> object.
 
-=item B<quantity> positive integer or zero
+=head2 price object
+
+The price the customer is subscribed to.
+
+This is a L<Net::API::Stripe::Price> object.
+
+=head2 quantity positive integer or zero
 
 The quantity of the plan to which the customer should be subscribed.
 
-=item B<subscription> string
+=head2 subscription string
 
 The subscription this subscription_item belongs to.
 
-=item B<tax_rates> array of hashes
+=head2 tax_rates array of hashes
 
 The tax rates which apply to this subscription_item. When set, the default_tax_rates on the subscription do not apply to this subscription_item.
 
 This is an array of L<Net::API::Stripe::Tax::Rate> objects.
 
-=back
-
 =head1 API SAMPLE
 
-	{
-	  "id": "si_fake123456789",
-	  "object": "subscription_item",
-	  "billing_thresholds": null,
-	  "created": 1571397912,
-	  "metadata": {},
-	  "plan": {
-		"id": "expert-monthly-jpy",
-		"object": "plan",
-		"active": true,
-		"aggregate_usage": null,
-		"amount": 8000,
-		"amount_decimal": "8000",
-		"billing_scheme": "per_unit",
-		"created": 1507273129,
-		"currency": "jpy",
-		"interval": "month",
-		"interval_count": 1,
-		"livemode": false,
-		"metadata": {},
-		"nickname": null,
-		"product": "prod_fake123456789",
-		"tiers": null,
-		"tiers_mode": null,
-		"transform_usage": null,
-		"trial_period_days": null,
-		"usage_type": "licensed"
-	  },
-	  "quantity": 1,
-	  "subscription": "sub_fake123456789",
-	  "tax_rates": []
-	}
+    {
+      "id": "si_fake123456789",
+      "object": "subscription_item",
+      "billing_thresholds": null,
+      "created": 1571397912,
+      "metadata": {},
+      "plan": {
+        "id": "expert-monthly-jpy",
+        "object": "plan",
+        "active": true,
+        "aggregate_usage": null,
+        "amount": 8000,
+        "amount_decimal": "8000",
+        "billing_scheme": "per_unit",
+        "created": 1507273129,
+        "currency": "jpy",
+        "interval": "month",
+        "interval_count": 1,
+        "livemode": false,
+        "metadata": {},
+        "nickname": null,
+        "product": "prod_fake123456789",
+        "tiers": null,
+        "tiers_mode": null,
+        "transform_usage": null,
+        "trial_period_days": null,
+        "usage_type": "licensed"
+      },
+      "quantity": 1,
+      "subscription": "sub_fake123456789",
+      "tax_rates": []
+    }
 
 =head1 HISTORY
 
